@@ -180,16 +180,17 @@ class Service(web.Application):
                 release=f"{self.SERVICE_NAME}@{os.getenv('GITLAB_COMMIT')}" if os.getenv('GITLAB_COMMIT') else None,
             )
 
-        if os.getenv("DATADOG_ENABLED"):
-            if os.getenv("DATADOG_SERVICE_NAME") and os.getenv("DATADOG_API_KEY") and os.getenv("DATADOG_APP_KEY"):
-                self.logging.info("[PLUGINS] DataDog enabled")
-                self.monitor = DataDogMonitor(
-                    host=os.getenv("DATADOG_HOST", '127.0.0.1'),
-                    service=os.getenv("DATADOG_SERVICE_NAME"),
-                    env=self.ENVIRONMENT,
-                    api_key=os.getenv("DATADOG_API_KEY"),
-                    app_key=os.getenv("DATADOG_APP_KEY")
-                )
+        if os.getenv("DD_SERVICE") and os.getenv("DD_API_KEY") and os.getenv("DD_API_KEY") and os.getenv("DD_ENV"):
+            self.logging.info(
+                f"[PLUGINS] DataDog enabled (service: {os.getenv('DD_SERVICE')}, env: {os.getenv('DD_ENV')})"
+            )
+            self.monitor = DataDogMonitor(
+                host=os.getenv("DD_HOST", '127.0.0.1'),
+                service=os.getenv("DD_SERVICE"),
+                env=os.getenv("DD_ENV"),
+                api_key=os.getenv("DD_API_KEY"),
+                app_key=os.getenv("DD_APP_KEY")
+            )
 
         host = os.getenv('SERVICE_HOST', '0.0.0.0')
         if not kwargs.get('bind_port'):
@@ -618,5 +619,8 @@ class Endpoint(web.RequestHandler):
 class HealthCheckEndpoint(Endpoint):
     methods = ['GET']
 
+    def _log(self) -> None:
+        return
+
     async def get(self, *args, **kwargs):
         return self.finish_with_ok_status()
